@@ -19,5 +19,9 @@
 API classes which make requests to a group of Yammer API endpoints.
 """
 
-from messages import MessagesAPI
-from users import UsersAPI
+from .messages import MessagesAPI
+from .users import UsersAPI
+from .threads import ThreadsAPI
+from .topics import TopicsAPI
+from .groups import GroupsAPI
+from .relationships import RelationshipsAPI
